@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 # SPDX-License-Identifier: LGPL-3.0-only
 
-"""library to interact with the Packet API"""
+"""library to interact with the Equinix Metal API"""
 
-__version__ = "1.44.0"
+__version__ = "1.44.2"
 __author__ = "Equinix Metal Engineers"
 __author_email__ = "support@equinixmetal.com"
 __license__ = "LGPL v3"
